###################################################
### chunk number 1: coin-setup
###################################################
options(prompt = "R> ")
library("coin")
set.seed(290875)
### get rid of the NAMESPACE
attach(asNamespace("coin"))

### use UML? http://argouml.tigris.org/

### extract slots of a class
c2t <- function(x) {        

    classdef <- getClassDef(x)

    extends <- names(classdef@contains)[1]
    if (!is.null(extends)) {
        eslots <- names(getClassDef(extends)@slots)
        slots <- classdef@slots[!names(classdef@slots) %in% eslots]
    } else {
        slots <- classdef@slots
    }

    RET <- cbind(names(slots), slots)
    attr(RET, "contains") <- extends 
    attr(RET, "name") <- x
    class(RET) <- "c2t"        
    RET
}
 
### pretty printing
toLatex.c2t <- function(object, center = TRUE, ...) {        

    RET <- c()

    if (center) RET <- c(RET, "\\begin{center}")

    ### class name
    RET <- c(RET, "\\begin{tabular}{ll}",
                  paste("\\multicolumn{2}{l}{Class \\Rclass{", 
                        attr(object, "name"), "}} \\\\", sep = "")) 

    ### extends?
    if (!is.null(attr(object, "contains")))
        RET <- c(RET, paste("\\multicolumn{2}{l}{Contains \\Rclass{", 
                            attr(object, "contains"), "}} \\\\", sep = ""))

    ### slots
    RET <- c(RET, " & \\\\", "Slot & Class \\\\ \\hline ",
             apply(object, 1, function(x) {
                 x <- cbind(paste("\\code{", x[1], "}", sep = ""),
                            paste("\\Rclass{", x[2], "}", sep = ""))
                 paste(paste(x, collapse = " & "), "\\\\")
             }),
             "\\hline")
    RET <- c(RET, "\\end{tabular}")

    if (center) RET <- c(RET, "\\end{center}")

    class(RET) <- "Latex"
    return(RET)
}


###################################################
### chunk number 2: IndependenceProblem
###################################################
toLatex(c2t("IndependenceProblem"))


###################################################
### chunk number 3: IndependenceTestProblem
###################################################
toLatex(c2t("IndependenceTestProblem"))


###################################################
### chunk number 4: IndependenceLinearStatistic
###################################################
toLatex(c2t("IndependenceLinearStatistic"))


###################################################
### chunk number 5: IndependenceTestStatistic
###################################################
toLatex(c2t("IndependenceTestStatistic"))


###################################################
### chunk number 6: ScalarIndependenceTestStatistic
###################################################
toLatex(c2t("ScalarIndependenceTestStatistic"))


###################################################
### chunk number 7: MaxTypeIndependenceTestStatistic
###################################################
toLatex(c2t("MaxTypeIndependenceTestStatistic"))


###################################################
### chunk number 8: QuadTypeIndependenceTestStatistic
###################################################
toLatex(c2t("QuadTypeIndependenceTestStatistic"))


###################################################
### chunk number 9: PValue
###################################################
toLatex(c2t("PValue"))


###################################################
### chunk number 10: NullDistribution
###################################################
toLatex(c2t("NullDistribution"))


###################################################
### chunk number 11: IndependenceTest
###################################################
toLatex(c2t("IndependenceTest"))


###################################################
### chunk number 12: coin-doxygen eval=FALSE
###################################################
## browseURL(system.file("documentation", "html", "index.html", 
##                       package = "coin"))


###################################################
### chunk number 13: js
###################################################
js <- jobsatisfaction
dimnames(js)[[2]] <- c("VeryDiss", "ModDiss", "ModSat", "VerySat")
ftable(Job.Satisfaction ~ Gender + Income, data = js)


###################################################
### chunk number 14: js-plot
###################################################
library("vcd")
cotabplot(js, split_vertical = TRUE, gp = gpar(fill = rev(gray.colors(4))),
          spacing = spacing_highlighting, 
          labeling_args = list(rot_labels = 0, varnames = FALSE, 
                               just_labels = c("center", "right")), 
          panel_args = list(margins = c(3,1,2,3.5)))


###################################################
### chunk number 15: jobsatisfaction-it
###################################################
it <- independence_test(js, teststat = "quad", distribution = asymptotic())
it


###################################################
### chunk number 16: jobsatisfaction-T
###################################################
statistic(it, "linear")


###################################################
### chunk number 17: jobsatisfaction-margin
###################################################
margin.table(js, 1:2)


###################################################
### chunk number 18: jobsatisfaction-stat
###################################################
statistic(it, "standardized")


###################################################
### chunk number 19: jobsatisfaction-max
###################################################
independence_test(js, teststat = "max")


###################################################
### chunk number 20: jobsatisfaction-minp
###################################################
pvalue(independence_test(js, teststat = "max"), 
       method = "single-step")


###################################################
### chunk number 21: jobsatisfaction-ordinal
###################################################
it <- independence_test(js, 
    scores = list(Job.Satisfaction = c(1, 3, 4, 5),
                  Income = c(3, 10, 20, 35)),
    distribution = approximate(B = 10000))
pvalue(it)


